#
# spec file for package tpm2.0-abrmd
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           tpm2.0-abrmd
Version:        1.2.0
Release:        lp150.1.1
Summary:        Intel's TCG Software Stack Access Broker & Resource Manager for TPM 2.0 chips
License:        BSD-2-Clause
Group:          Productivity/Security
Url:            https://github.com/01org/tpm2-abrmd
Source0:        https://github.com/01org/tpm2-abrmd/releases/download/1.2.0/tpm2-abrmd-%{version}.tar.gz
BuildRequires:  autoconf-archive
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(sapi)
Requires(pre):  pwdutils
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Patch1:         support_dbus_activation.diff

%description
The tpm2.0-abrmd package provides the TPM2 Access Broker & Resource Manager.
This is a daemon service that coordinates requests to the TPM2 chip via
Intel's TPM 2.0 software stack.

%package devel
Summary:        Development headers the Access Broker & Resource Manager for TPM 2.0 chips
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libtcti-tabrmd0 = %{version}
Requires:       tpm2.0-abrmd = %{version}

%description devel
This package provides the development files for the Access Broker & Resource
Manager for coordinating access to TPM 2.0 chips.

%package -n libtcti-tabrmd0
Summary:        Client interface library for tpm2-abrmd
Group:          System/Libraries

%description -n libtcti-tabrmd0
This library allows to interact with the tpm2-abrmd daemon. It is intended for
use with the SAPI library (libsapi) like any other TCTI.

%post -n libtcti-tabrmd0 -p /sbin/ldconfig
%postun -n libtcti-tabrmd0 -p /sbin/ldconfig

%prep
%setup -q -n tpm2-abrmd-%{version}
# can't apply that at the moment, because a whitelisting in rpmlint is missing
# for the given service name
#%patch1 -p1

%build
export CFLAGS="%optflags -fPIE"
export LDFLAGS="-pie -fPIE"
autoreconf
%configure --disable-static --with-udevrulesdir=%{_udevrulesdir} --with-systemdsystemunitdir=%{_unitdir}
make %{?_smp_mflags} PTHREAD_LDFLAGS=-pthread

# TODO: add the tss user again
%install
%make_install
# don't package libtool files as is best practice
find %{buildroot} -type f -name "*.la" -delete -print
# rename the rules file to have a numbered prefix as all others have, too
%define udev_rule_file 90-tpm.rules
mv %{buildroot}%{_udevrulesdir}/tpm-udev.rules %{buildroot}%{_udevrulesdir}/%{udev_rule_file}
ln -sv %{_sbindir}/service %{buildroot}%{_sbindir}/rctpm2-abrmd
# don't install the systemd preset, our presets are handled by
# systemd-presets-* packages
rm %{buildroot}/usr/lib*/systemd/system-preset/tpm2-abrmd.preset

%pre
# the same user is employed by trousers (and was employed by the old
# resourcemgr shipped with the tpm2-0-tss package):
#
# trousers just needs those accounts for dropping privileges to. The service
# starts as root and uses set*id to drop to tss, after the tpm device has been
# opened.
#
# tpm2-abrmd has no set*id handling and thus requires /dev/tpm to be owned
# by the tss user. Therefore we also need to install a udev rule file.
#
# trousers was here first and created the user like this, also giving it a
# home in /var/lib/tpm. I don't think the home directory is used by any of
# both packages ATM. Trousers is keeping state there, but the directory is
# owned by root and files are opened before dropping privileges. The passwd
# entry seems not to be evaluated.
#
# so I guess we can share the account between the two packages for now.
%_bindir/getent group tss >/dev/null || %{_sbindir}/groupadd -g 98 tss
%_bindir/getent passwd tss >/dev/null || \
	%{_sbindir}/useradd -u 98 -o -g tss -s /bin/false -c "TSS daemon" \
	-d %{_localstatedir}/lib/tpm tss
%service_add_pre tpm2-abrmd.service

%post
%service_add_post tpm2-abrmd.service
%_bindir/udevadm trigger -s tpm || :

%postun
%service_del_postun tpm2-abrmd.service

%preun
%service_del_preun tpm2-abrmd.service

%files
%defattr(-,root,root)
%doc *.md LICENSE
%{_udevrulesdir}/%{udev_rule_file}
%{_mandir}/man7/tcti-*
%{_mandir}/man8/tpm2-*
%{_sbindir}/tpm2-abrmd
%{_sbindir}/rctpm2-abrmd
%{_unitdir}/tpm2-abrmd.service
%config %{_sysconfdir}/dbus-1/system.d/tpm2-abrmd.conf
# see patch1
#%{_datadir}/dbus-1/system-services/com.intel.tss2.Tabrmd.service

%files devel
%defattr(-,root,root)
%{_includedir}/tcti
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/tss2_*

%files -n libtcti-tabrmd0
%defattr(-,root,root)
%{_libdir}/libtcti-tabrmd.so.*

%changelog
* Thu Feb 22 2018 matthias.gerstner@suse.com
- update to upstream version 1.2.0:
  - Limit maximum number of active sessions per connection with '--max-sessions'.
  - Flush all transient objects and sessions on daemon start with '--flush-all'.
  - Allow passing of sessions across connections with ContextSave / Load.
  - Unref the GUnixFDList returned by GIO / dbus in the TCTI init function.
    This fixes a memory leak in the TCTI library.
- correctly trigger udev to update /dev/tpm* permissions after package
  installation. (bnc#1078687)
- prepared support_dbus_activation.diff patch which adds D-Bus activation, but
  can't use it yet due to rpmlint
* Wed Nov 15 2017 matthias.gerstner@suse.com
- fix_service_paths.diff: fixed broken systemd service unit (bnc#1066123). the
  service unit file in the upstream distribution tarball is already configured
  and looks for binaries and configuration files in the /usr/local prefix
  which is wrong.
* Fri Sep  1 2017 matthias.gerstner@suse.com
- package version symlink correctly, belongs into the lib package itself, not
  the -devel.
* Wed Aug 30 2017 matthias.gerstner@suse.com
- update to upstream version 1.1.1 which fixes some local denial-of-service
  security issues among other things:
  - Replace use of sigaction with g_unix_signal_* stuff from glib.
  - Rewrite of INSTALL.md including info on custom configure script options.
  - Default value for --with-simulatorbin configure option has been removed.
  New default behavior is to disable integration tests.
  - CommandSource will no longer reject commands without parameters.
  - Unit tests updated to use cmocka v1.0.0 API.
  - Integration tests now run daemon under valgrind memcheck and fail when
  errors are found.
  - CommandSource now tracks max FD in set of client FDs to prevent unnecessary
  iterations over FD_SETSIZE fds.
- no longer call bootstrap and switch to the release upstream tarball which
  has now been fixed to contain all necessary files
* Thu Jul 20 2017 matthias.gerstner@suse.com
- first version of the new arbmd resource manager from Intel's tpm2 stack.
  This will replace the old resourcemgr previously shipped with the
  tpm2-0-tss package.
